import { globalLookup } from '@/hook/global';
import formatTime from '@/hook/wave-view/format-time';
import { reactive } from 'vue';

export const StaticCursor = reactive({
    label: '',
    show: false,
    currentTime: 0,
    left: 0,
    updateLabel(timescale) {
        this.label = formatTime(this.currentTime, timescale);
        this.show = true;
    },
    updateLeft() {
        this.left = calcCursorLeft(this.currentTime);
        this.show = true;
    }
});

export function changeCursorLocation() {    
    StaticCursor.show = true;
    const pstate = globalLookup.pstate;
    if (pstate) {
        const { xCursor, xOffset, xScale, tgcd, timescale } = pstate;
        const currentTime = Math.round((xCursor - xOffset) / xScale) * tgcd;
        StaticCursor.currentTime = currentTime;
        StaticCursor.updateLabel(timescale);
        StaticCursor.updateLeft();
    }
}

/**
 * @description 给出当前的时间，比如 23ns，计算当前这个点应该相对于左侧偏移多少
 * @param {number} currentTime
 * @returns {number} 
 */
export function calcCursorLeft(currentTime) {
    const pstate = globalLookup.pstate;
    if (pstate) {
        const { xOffset, xScale, tgcd, timescale } = pstate;
        const xCursor = (currentTime / tgcd) * xScale + xOffset;
        return xCursor;
    }
    return 0;
}

export const MovingCursor = reactive({

});